pub struct Opts {
pub no_environment: bool,
pub skip_healthchecks: bool,
pub deny_warnings: bool,
pub paths_toml: Vec<PathBuf>,
pub paths_json: Vec<PathBuf>,
pub paths_yaml: Vec<PathBuf>,
pub paths: Vec<PathBuf>,
pub config_dirs: Vec<PathBuf>,
pub disable_env_var_interpolation: bool,
}Fields
no_environment: boolDisables environment checks. That includes component checks and health checks.
skip_healthchecks: boolDisables health checks during validation.
deny_warnings: boolFail validation on warnings that are probably a mistake in the configuration or are recommended to be fixed.
paths_toml: Vec<PathBuf>Vector config files in TOML format to validate.
paths_json: Vec<PathBuf>Vector config files in JSON format to validate.
paths_yaml: Vec<PathBuf>Vector config files in YAML format to validate.
paths: Vec<PathBuf>Any number of Vector config files to validate.
Format is detected from the file name.
If none are specified, the default config path /etc/vector/vector.yaml
is targeted.
config_dirs: Vec<PathBuf>Read configuration from files in one or more directories. File format is detected from the file name.
Files not ending in .toml, .json, .yaml, or .yml will be ignored.
disable_env_var_interpolation: boolDisable interpolation of environment variables in configuration files.